@@ -11,17 +11,14 @@ use warnings;
 use strict;
 
 package Audio::MPD;
-BEGIN {
-  $Audio::MPD::VERSION = '1.110560';
-}
 # ABSTRACT: class to talk to MPD (Music Player Daemon) servers
-
+$Audio::MPD::VERSION = '2.004';
 use Audio::MPD::Common::Item;
 use Audio::MPD::Common::Stats;
 use Audio::MPD::Common::Status;
 use Audio::MPD::Common::Output;
 use Encode;
-use IO::Socket;
+use IO::Socket::IP;
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::SemiAffordanceAccessor;
@@ -41,7 +38,7 @@ has collection => ( ro, lazy_build, isa=>'Audio::MPD::Collection' );
 has playlist   => ( ro, lazy_build, isa=>'Audio::MPD::Playlist'   );
 has version    => ( rw );
 
-has _socket    => ( rw, isa=>'IO::Socket::INET' );
+has _socket    => ( rw, isa=>'IO::Socket' );
 
 
 #--
@@ -96,11 +93,21 @@ sub _connect_to_mpd_server {
     my ($self) = @_;
 
     # try to connect to mpd.
-    my $socket = IO::Socket::INET->new(
-        PeerAddr => $self->host,
-        PeerPort => $self->port,
-    )
-    or die "Could not create socket: $!\n";
+    my $socket;
+
+    if ($self->host =~ m{^/}) {
+        eval q{use IO::Socket::UNIX qw(); 1}
+            or die "Could not load IO::Socket::UNIX: $@\n";
+        $socket = IO::Socket::UNIX->new($self->host)
+            or die "Could not create socket: $!\n";
+    }
+    else {
+        $socket = IO::Socket::IP->new(
+            PeerAddr => $self->host,
+            PeerPort => $self->port,
+        )
+        or die "Could not create socket: $!\n";
+    }
 
     # parse version information.
     my $line = $socket->getline;
@@ -465,7 +472,7 @@ no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
-
+__END__
 
 =pod
 
@@ -475,7 +482,7 @@ Audio::MPD - class to talk to MPD (Music Player Daemon) servers
 
 =head1 VERSION
 
-version 1.110560
+version 2.004
 
 =head1 SYNOPSIS
 
@@ -516,7 +523,7 @@ would be then on your own to deal with disconnections.
 To search the collection, use the C<collection()> accessor, returning the
 associated L<Audio::MPD::Collection> object. You will then be able to call:
 
-    $mpd->collection->random_song;
+    $mpd->collection->all_songs;
 
 See L<Audio::MPD::Collection> documentation for more details on available
 methods.
@@ -778,7 +785,7 @@ You can look for information on this module at:
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/Audio-MPD>
+L<http://metacpan.org/release/Audio-MPD>
 
 =item * See open / report bugs
 
@@ -814,7 +821,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
